@@ -7,7 +7,7 @@ use Mojo::Util qw/quote deprecated/;
 use Mojo::IOLoop;
 
 
-our $VERSION = 0.05;
+our $VERSION = 0.06;
 
 
 my $WK_PATH = '/.well-known/host-meta';
@@ -132,7 +132,7 @@ sub _fetch_hostmeta {
   };
 
   # Check if security is forced
-  my $secure = $_[-1] && $_[-1] eq '-secure' ? pop : 0;
+  my $secure = defined $_[-1] && $_[-1] eq '-secure' ? pop : 0;
 
   # Get callback
   my $cb = pop if ref($_[-1]) && ref($_[-1]) eq 'CODE';
@@ -242,7 +242,7 @@ sub _serve_hostmeta {
   my $xrd = shift;
 
   # Ignore security flag
-  pop if $_[-1] && $_[-1] eq '-secure';
+  pop if defined $_[-1] && $_[-1] eq '-secure';
 
   # Ignore header information
   shift if $_[0] && ref($_[0]) && ref($_[0]) eq 'HASH';
@@ -305,7 +305,7 @@ __END__
 
 =head1 NAME
 
-Mojolicious::Plugin::HostMeta - Serve and Retrieve Host-Meta documents
+Mojolicious::Plugin::HostMeta - Serve and Retrieve Host-Meta Documents
 
 
 =head1 SYNOPSIS
